<?php
// Include the database connection file
include '../../includes/connection.php';

// Check if the required data is sent via POST
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $email = $_POST['email'];

    // Check if email is empty
    if (empty($email)) {
        echo json_encode(["status" => "error", "message" => "Email is required."]);
        exit();
    }

    // Check if email exists in Users table
    $sql = "SELECT * FROM Users WHERE email = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("s", $email);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows === 0) {
        echo json_encode(["status" => "error", "message" => "Email not registered."]);
        exit();
    }

    $user = $result->fetch_assoc();

    // Check user status
    if ($user['user_status'] !== 'active') {
        echo json_encode(["status" => "error", "message" => "User account is banned by admin. Please contact support."]);
        exit();
    }

    // Define which columns to include from the Plans table
    $columns = [
        'id',
        'plan_name',
        'plan_type',
        'price',
        'duration_days',
        'description'
    ];
    
    // Create the SQL query dynamically based on the selected columns
    $columnList = implode(', ', $columns);
    $planSql = "SELECT $columnList FROM Plans WHERE plan_status = 'Active'";
    
    $planStmt = $conn->prepare($planSql);
    $planStmt->execute();
    $planResult = $planStmt->get_result();

    if ($planResult->num_rows === 0) {
        echo json_encode(["status" => "error", "message" => "No active subscription plans available."]);
        exit();
    }

    $plans = [];
    while ($plan = $planResult->fetch_assoc()) {
        $plans[] = $plan;
    }

    echo json_encode(["status" => "success", "message" => "User authenticated successfully.", "plans" => $plans]);

    // Close the statements and connection
    $stmt->close();
    $planStmt->close();
    $conn->close();
} else {
    echo json_encode(["status" => "error", "message" => "Invalid request method."]);
}
?>
